#include <utility>
#include <string>
#include <cassert>
#include <cstring>
#include <cmath>
#include <vector>
#include <algorithm>
#include <bitset>
#include "streamcorr.h"

#include <sstream>
using namespace std;

typedef vector<vector<int> > vvi;
typedef vector<int> vi;

const int MAXN = 300;

/* Check one test case.  Returns false if there were no more test
 * cases to check. */
bool check_case(int cas) {
    int n;
    judge_in >> n;

    bitset<MAXN> target[MAXN];
    for(int i = 0; i < n; ++i) {
        string s;
        judge_in >> s;
        reverse(s.begin(), s.end());
        target[i] = bitset<MAXN>(s);
    }

    int m, opt_m;
    judge_ans >> opt_m;
    int x, y;
    for (int i = 0; i < opt_m; i++)
        judge_ans >> x >> y;

    if (!(author_out >> m))
        report_error("Can't read answer");

    if (m != opt_m)
        report_error("Incorrect road network size");
        //report_error("Not the optimal answer: team says %d vs ours %d", m, opt_m);

    bitset<MAXN> trans[MAXN];
    for (int i = 0; i < m; i++)
    {
        int x, y;
        if (!(author_out >> x >> y))
            report_error("Incorrect output syntax (cannot read a road)");
            //report_error("Can't read an edge");
        if (x <= 0 || x > n || y <= 0 || y > n)
            report_error("Junction number out of range");
            //report_error("Vertex out of range");
        x--; y--;
        trans[x][y] = 1;
    }

    for (int k = 0; k < n; k++)
        for (int i = 0; i < n; i++)
            for (int j = 0; j < n; j++)
                trans[i][j] = trans[i][j] || (trans[i][k] && trans[k][j]);

    for (int i = 0; i < n; i++)
        for (int j = 0; j < n; j++) if (i != j)
            if (trans[i][j] != target[i][j])
                report_error("Reachability list of your road network does not match the input");
                //report_error("The graph's transitive closure is not the same as in the input. %d not connected to %d, case %d", i + 1, j + 1, cas);

    return true;
}

int main(int argc, char **argv) {
    init_io(argc, argv);

    int t;
    judge_in >> t;

    for (int cas = 0; cas < t; cas++)
        check_case(cas);

    /* Check for trailing output in author file. */
    string trash;
    if (author_out >> trash) {
        report_error("Too much data at the end of your submission");
        //report_error("Trailing output");
    }

    accept();
}
