/* Version of corr.h using streams for input (much nicer handling of
 * strings, no need to specify some max-length for them).
 *
 * Still uses cstdio for output (because varargs are very convenient),
 * the mixing is a bit ugly.
 */
#ifndef H_STREAMCORR_H
#define H_STREAMCORR_H

#include <cstdarg>
#include <cstdio>
#include <cassert>
#include <cstdlib>
#include <iostream>
#include <fstream>

const int EXIT_AC = 0;
const int EXIT_WA = 1;

#define USAGE "%s: judge_in judge_ans < author_out\n"

std::ifstream judge_in, judge_ans;
std::istream author_out(std::cin.rdbuf());

void vreport_feedback(const char *msg, va_list pvar) {
  vprintf(msg, pvar);
  printf("\n");
}

void report_error(const char *err, ...) {
   va_list pvar;
   va_start(pvar, err);
   vreport_feedback(err, pvar);
   exit(EXIT_WA);
}

void accept() {
  exit(EXIT_AC);
}

void init_io(int argc, char **argv) {

   if(argc < 3) {
     fprintf(stderr, USAGE, argv[0]);
     printf("Usage: %s judgein judgeans < userout\n", argv[0]);
     exit(3);
   }

   judge_in.open(argv[1], std::ios_base::in);
   if (judge_in.fail()) {
     printf("%s: failed to open %s\n", argv[0], argv[1]);
   }

   judge_ans.open(argv[2], std::ios_base::in);

   author_out.rdbuf(std::cin.rdbuf());
}

#endif /* H_STREAMCORR_H */
